==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/autoresponder/translations/autoresponder_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversar</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Sólo para la primera vez</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Responder a las conferencias</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Estado invisible</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Estado ocupado</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Estado disponible</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Respuesta automática</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Texto de respuesta automática</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Seleccionar Estado</translation>
    </message>
</context>
<context>
    <name>AutoResponder</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation>RESPUESTA AUTOMÁTICA KADU:</translation>
    </message>
</context>
<context>
    <name>AutoresponderConfigurator</name>
    <message>
        <source>I am busy.</source>
        <translation>Estoy ocupado</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/autoresponder/translations/autoresponder_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversar</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Sólo para la primera vez</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Responder a las conferencias</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Estado invisible</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Estado ocupado</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Estado disponible</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Respuesta automática</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Texto de respuesta automática</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Seleccionar Estado</translation>
    </message>
</context>
<context>
    <name>AutoresponderConfigurator</name>
    <message>
        <source>I am busy.</source>
        <translation>Estoy ocupado</translation>
    </message>
</context>
<context>
    <name>AutoresponderMessageFilter</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
